/*
  ******************************************************************************
  * @file    apt32f103_interrupt.c
  * @author  
  * @version V1.00
  * @date    2023/02/01
  ******************************************************************************
  *THIS SOFTWARE WHICH IS FOR ILLUSTRATIVE PURPOSES ONLY WHICH PROVIDES 
  *CUSTOMER WITH CODING INFORMATION REGARDING THEIR PRODUCTS.
  *APT CHIP SHALL NOT BE HELD RESPONSIBILITY ADN LIABILITY FOR ANY DIRECT, 
  *INDIRECT DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF 
  *SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION 
  *CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.AND APT CHIP RESERVES 
  *THE RIGHT TO MAKE CHANGES IN THE SOFTWARE WITHOUT NOTIFICATION
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "apt32f103.h"
#include "apt32f103_adc.h"
#include "apt32f103_bt.h"
#include "apt32f103_countera.h"
#include "apt32f103_crc.h"
#include "apt32f103_ept.h"
#include "apt32f103_et.h"
#include "apt32f103_gpio.h"
#include "apt32f103_gpt.h"
#include "apt32f103_i2c.h"
#include "apt32f103_ifc.h"
#include "apt32f103_lpt.h"
#include "apt32f103_rtc.h"
#include "apt32f103_sio.h"
#include "apt32f103_spi.h"
#include "apt32f103_syscon.h"
#include "apt32f103_uart.h"
#include "apt32f103_usart.h"
#include "apt32f103_wwdt.h"
#include "apt32f103_dma.h"
#include "apt32f103_types_local.h"
#include "tkey.h"
/* defines -------------------------------------------------------------------*/
U32_T R_CMPA_BUF,R_CMPB_BUF;

/* externs--------------------------------------------------------------------*/
extern void delay_nms(unsigned int t);

/*************************************************************/
//SYSCON Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SYSCONIntHandler(void) 
{
    // ISR content ...
	if((SYSCON->MISR&ISOSC_ST)==ISOSC_ST)				//ISOSC stable interrupt
	{
		SYSCON->ICR = ISOSC_ST;
	} 
	else if((SYSCON->MISR&IMOSC_ST)==IMOSC_ST)			//IMOSC stable interrupt
	{
		SYSCON->ICR = IMOSC_ST;
	} 
	else if((SYSCON->MISR&EMOSC_ST)==EMOSC_ST)			//EMOSC stable interrupt
	{
		SYSCON->ICR = EMOSC_ST;
	} 
	else if((SYSCON->MISR&HFOSC_ST)==HFOSC_ST)			//HFOSC stable interrupt
	{
		SYSCON->ICR = HFOSC_ST;
	} 
	else if((SYSCON->MISR&SYSCLK_ST)==SYSCLK_ST)		//SYSCLK change end & stable interrupt
	{
		SYSCON->ICR = SYSCLK_ST;
	}
	else if((SYSCON->MISR&IWDT_INT_ST)==IWDT_INT_ST)	//IWDT alarm window interrupt
	{
		SYSCON->ICR = IWDT_INT_ST;
		SYSCON_IWDCNT_Reload(); 
	}
	else if((SYSCON->MISR&WKI_INT_ST)==WKI_INT_ST)
	{
		SYSCON->ICR = WKI_INT_ST;
	}
	else if((SYSCON->MISR&RAMERRINT_ST)==RAMERRINT_ST)	//SRAM check fail interrupt
	{
		SYSCON->ICR = RAMERRINT_ST;
	}
	else if((SYSCON->MISR&LVD_INT_ST)==LVD_INT_ST)		//LVD threshold interrupt
	{
		SYSCON->ICR = LVD_INT_ST;
	}
	else if((SYSCON->MISR&HWD_ERR_ST)==HWD_ERR_ST)		//Hardware Divider divisor = 0 interrupt
	{
		SYSCON->ICR = HWD_ERR_ST;
	}
	else if((SYSCON->MISR&EFL_ERR_ST)==EFL_ERR_ST)		//Flash check fail interrupt
	{
		SYSCON->ICR = EFL_ERR_ST;
	}
	else if((SYSCON->MISR&OPTERR_INT)==OPTERR_INT)		//Option load fail interrupt
	{
		SYSCON->ICR = OPTERR_INT;
	}
	else if((SYSCON->MISR&EM_CMLST_ST)==EM_CMLST_ST)	//EMOSC clock monitor fail interrupt
	{
		SYSCON->ICR = EM_CMLST_ST;
	}
	else if((SYSCON->MISR&EM_EVTRG0_ST)==EM_EVTRG0_ST)	//Event Trigger Channel 0 Interrupt
	{
		SYSCON->ICR = EM_EVTRG0_ST;
	}
	else if((SYSCON->MISR&EM_EVTRG1_ST)==EM_EVTRG1_ST)	//Event Trigger Channel 1 Interrupt
	{
		SYSCON->ICR = EM_EVTRG1_ST;
	}
	else if((SYSCON->MISR&EM_EVTRG2_ST)==EM_EVTRG2_ST)	//Event Trigger Channel 2 Interrupt
	{
		SYSCON->ICR = EM_EVTRG2_ST;
	}
	else if((SYSCON->MISR&EM_EVTRG3_ST)==EM_EVTRG3_ST)	//Event Trigger Channel 3 Interrupt
	{
		SYSCON->ICR = EM_EVTRG3_ST;
	}
	else if((SYSCON->MISR&CMD_ERR_ST)==CMD_ERR_ST)		//Command error interrupt
	{
		SYSCON->ICR = CMD_ERR_ST;
	}
}
/*************************************************************/
//IFC Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
volatile U8_T ifc_step,f_Drom_write_complete;
void IFCIntHandler(void) 
{
    // ISR content ...
	if(IFC->MISR&ERS_END_INT)			
	{
		IFC->ICR=ERS_END_INT;
		if((ifc_step==1)&&(f_Drom_writing==1))
		{
			SetUserKey;
			IFC->CMR=0x01;					//将页缓存的数据写入闪存中
			IFC->FM_ADDR=R_INT_FlashAdd;		//
			IFC->CR=0X01;					//Start Program
			ifc_step=2;
		}
	}
	else if(IFC->MISR&RGM_END_INT)		
	{
		IFC->ICR=RGM_END_INT;
		if((ifc_step==2)&&(f_Drom_writing==1))
		{
			f_Drom_write_complete=1;
		}
	}
	else if(IFC->MISR&PEP_END_INT)		
	{
		IFC->ICR=PEP_END_INT;
		if((ifc_step==0)&&(f_Drom_writing==1))
		{
			SetUserKey;
			IFC->CMR=0x02;					//页擦除
			IFC->FM_ADDR=R_INT_FlashAdd;			//
			IFC->CR=0X01;					//Start Program
			ifc_step=1;
		}
	}
	else if(IFC->MISR&PROT_ERR_INT)		
	{
		IFC->ICR=PROT_ERR_INT;
	}
	else if(IFC->MISR&UDEF_ERR_INT)		
	{
		IFC->ICR=UDEF_ERR_INT;
	}
	else if(IFC->MISR&ADDR_ERR_INT)		
	{
		IFC->ICR=ADDR_ERR_INT;
	}
	else if(IFC->MISR&OVW_ERR_INT)		
	{
		IFC->ICR=OVW_ERR_INT;
	}
}
/*************************************************************/
//ADC Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void ADCIntHandler(void) 
{
    // ISR content ...
	if((ADC0->SR&ADC12_EOC)==ADC12_EOC)				//ADC EOC interrupt
	{
		ADC0->CSR = ADC12_EOC;
	}
	else if((ADC0->SR&ADC12_READY)==ADC12_READY)	//ADC READY interrupt
	{
		ADC0->CSR = ADC12_READY;
	}
	else if((ADC0->SR&ADC12_OVR)==ADC12_OVR)		//ADC OVR interrupt
	{
		ADC0->CSR = ADC12_OVR;
	}
	else if((ADC0->SR&ADC12_CMP0H)==ADC12_CMP0H)	//ADC CMP0H interrupt
	{
		ADC0->CSR = ADC12_CMP0H;
	}
	else if((ADC0->SR&ADC12_CMP0L)==ADC12_CMP0L)	//ADC CMP0L interrupt.
	{
		ADC0->CSR = ADC12_CMP0L;
	}
	else if((ADC0->SR&ADC12_CMP1H)==ADC12_CMP1H)	//ADC CMP1H interrupt.
	{
		ADC0->CSR = ADC12_CMP1H;
	}
	else if((ADC0->SR&ADC12_CMP1L)==ADC12_CMP1L)	//ADC CMP1L interrupt.
	{
		ADC0->CSR = ADC12_CMP1L;
	}
	else if((ADC0->SR&ADC12_SEQ_END0)==ADC12_SEQ_END0) //ADC SEQ0 interrupt,SEQ1~SEQ15 replace the parameter with ADC12_SEQ_END1~ADC12_SEQ_END15
	{
		ADC0->CSR = ADC12_SEQ_END0;
	}
	else if((ADC0->SR&ADC12_SEQ_END1)==ADC12_SEQ_END1)
	{
		ADC0->CSR = ADC12_SEQ_END1;
	}
	else if((ADC0->SR&ADC12_SEQ_END2)==ADC12_SEQ_END2)
	{
		ADC0->CSR = ADC12_SEQ_END2;
	}
	else if((ADC0->SR&ADC12_SEQ_END3)==ADC12_SEQ_END3)
	{
		ADC0->CSR = ADC12_SEQ_END3;
	}
	else if((ADC0->SR&ADC12_SEQ_END4)==ADC12_SEQ_END4)
	{
		ADC0->CSR = ADC12_SEQ_END4;
	}
	else if((ADC0->SR&ADC12_SEQ_END5)==ADC12_SEQ_END5)
	{
		ADC0->CSR = ADC12_SEQ_END5;
	}
	else if((ADC0->SR&ADC12_SEQ_END6)==ADC12_SEQ_END6)
	{
		ADC0->CSR = ADC12_SEQ_END6;
	}
	else if((ADC0->SR&ADC12_SEQ_END7)==ADC12_SEQ_END7)
	{
		ADC0->CSR = ADC12_SEQ_END7;
	}
	else if((ADC0->SR&ADC12_SEQ_END8)==ADC12_SEQ_END8)
	{
		ADC0->CSR = ADC12_SEQ_END8;
	}
	else if((ADC0->SR&ADC12_SEQ_END9)==ADC12_SEQ_END9)
	{
		ADC0->CSR = ADC12_SEQ_END9;
	}
	else if((ADC0->SR&ADC12_SEQ_END10)==ADC12_SEQ_END10)
	{
		ADC0->CSR = ADC12_SEQ_END10;
	}
	else if((ADC0->SR&ADC12_SEQ_END11)==ADC12_SEQ_END11)
	{
		ADC0->CSR = ADC12_SEQ_END11;
	}
	else if((ADC0->SR&ADC12_SEQ_END12)==ADC12_SEQ_END12)
	{
		ADC0->CSR = ADC12_SEQ_END12;
	}
	else if((ADC0->SR&ADC12_SEQ_END13)==ADC12_SEQ_END13)
	{
		ADC0->CSR = ADC12_SEQ_END13;
	}
	else if((ADC0->SR&ADC12_SEQ_END14)==ADC12_SEQ_END14)
	{
		ADC0->CSR = ADC12_SEQ_END14;
	}
	else if((ADC0->SR&ADC12_SEQ_END15)==ADC12_SEQ_END15)
	{
		ADC0->CSR = ADC12_SEQ_END15;
	}
}
/*************************************************************/
//EPT0 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EPT0IntHandler(void) 
{
    // ISR content ...
	if((EPT0->MISR&EPT_TRGEV0_INT)==EPT_TRGEV0_INT)			//TRGEV0 interrupt
	{
		EPT0->ICR=EPT_TRGEV0_INT;
	}
	else if((EPT0->MISR&EPT_TRGEV1_INT)==EPT_TRGEV1_INT)	//TRGEV1 interrupt
	{
		EPT0->ICR=EPT_TRGEV1_INT;
	}
	else if((EPT0->MISR&EPT_TRGEV2_INT)==EPT_TRGEV2_INT)	//TRGEV2 interrupt
	{
		EPT0->ICR=EPT_TRGEV2_INT;
	}
	else if((EPT0->MISR&EPT_TRGEV3_INT)==EPT_TRGEV3_INT)	//TRGEV3 interrupt
	{
		EPT0->ICR=EPT_TRGEV3_INT;
	}	
	else if((EPT0->MISR&EPT_CAP_LD0)==EPT_CAP_LD0)			//Capture Load to CMPA interrupt
	{
		EPT0->ICR=EPT_CAP_LD0;
		EXTI_trigger_CMD(DISABLE,EXI_PIN0,_EXIRT);
		EXTI_trigger_CMD(ENABLE,EXI_PIN0,_EXIFT);
		
		//R_CMPA_BUF=EPT0->CMPA;			//period counter
	}
	else if((EPT0->MISR&EPT_CAP_LD1)==EPT_CAP_LD1)			//Capture Load to CMPB interrupt
	{
		EPT0->ICR=EPT_CAP_LD1;
		EXTI_trigger_CMD(ENABLE,EXI_PIN0,_EXIRT);
		EXTI_trigger_CMD(DISABLE,EXI_PIN0,_EXIFT);
		//R_CMPB_BUF=EPT0->CMPB;			//Duty counter
	}
	else if((EPT0->MISR&EPT_CAP_LD2)==EPT_CAP_LD2)			//Capture Load to CMPC interrupt
	{
		EPT0->ICR=EPT_CAP_LD2;
	}
	else if((EPT0->MISR&EPT_CAP_LD3)==EPT_CAP_LD3)			//Capture Load to CMPD interrupt
	{
		EPT0->ICR=EPT_CAP_LD3;
	}
	else if((EPT0->MISR&EPT_CAU)==EPT_CAU)					//Up-Counting phase CNT = CMPA interrupt
	{
		EPT0->ICR=EPT_CAU;
	}
	else if((EPT0->MISR&EPT_CAD)==EPT_CAD)					//Down-Counting phase CNT = CMPA interrupt
	{
		EPT0->ICR=EPT_CAD;
	}
	else if((EPT0->MISR&EPT_CBU)==EPT_CBU)					//Up-Counting phase CNT = CMPB interrupt 
	{
		EPT0->ICR=EPT_CBU;
	}
	else if((EPT0->MISR&EPT_CBD)==EPT_CBD)					//Down-Counting phase CNT = CMPB interrupt
	{
		EPT0->ICR=EPT_CBD;
	}
	else if((EPT0->MISR&EPT_CCU)==EPT_CCU)					//Up-Counting phase CNT = CMPC interrupt 
	{
		EPT0->ICR=EPT_CCU;
	}
	else if((EPT0->MISR&EPT_CCD)==EPT_CCD)					//Down-Counting phase CNT = CMPC interrupt
	{
		EPT0->ICR=EPT_CCD;
	}
	else if((EPT0->MISR&EPT_CDU)==EPT_CDU)					//Up-Counting phase CNT = CMPD interrupt
	{
		EPT0->ICR=EPT_CDU;
	}
	else if((EPT0->MISR&EPT_CDD)==EPT_CDD)					//Down-Counting phase CNT = CMPD interrupt
	{
		EPT0->ICR=EPT_CDD;
	}
	else if((EPT0->MISR&EPT_PEND)==EPT_PEND)				//End of cycle interrupt
	{
		EPT0->ICR=EPT_PEND;
	}
	//Emergency interruption
	if((EPT0->EMMISR&EPT_EP0_EMINT)==EPT_EP0_EMINT)			//interrupt flag of EP0 event
	{
		EPT0->EMICR=EPT_EP0_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP1_EMINT)==EPT_EP1_EMINT)	//interrupt flag of EP1 event
	{
		EPT0->EMICR=EPT_EP1_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP2_EMINT)==EPT_EP2_EMINT)	//interrupt flag of EP2 event
	{
		EPT0->EMICR=EPT_EP2_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP3_EMINT)==EPT_EP3_EMINT)	//interrupt flag of EP3 event
	{
		EPT0->EMICR=EPT_EP3_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP4_EMINT)==EPT_EP4_EMINT)	//interrupt flag of EP4 event
	{
		EPT0->EMICR=EPT_EP4_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP5_EMINT)==EPT_EP5_EMINT)	//interrupt flag of EP5 event
	{
		EPT0->EMICR=EPT_EP5_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP6_EMINT)==EPT_EP6_EMINT)	//interrupt flag of EP6 event
	{
		EPT0->EMICR=EPT_EP6_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EP7_EMINT)==EPT_EP7_EMINT)	//interrupt flag of EP7 event
	{
		EPT0->EMICR=EPT_EP7_EMINT;
	}
	else if((EPT0->EMMISR&EPT_CPU_FAULT_EMINT)==EPT_CPU_FAULT_EMINT)	//interrupt flag of CPU_FAULT event
	{
		EPT0->EMICR=EPT_CPU_FAULT_EMINT;
	}
	else if((EPT0->EMMISR&EPT_MEM_FAULT_EMINT)==EPT_MEM_FAULT_EMINT)	//interrupt flag of MEM_FAULT event
	{
		EPT0->EMICR=EPT_MEM_FAULT_EMINT;
	}
	else if((EPT0->EMMISR&EPT_EOM_FAULT_EMINT)==EPT_EOM_FAULT_EMINT)	//interrupt flag of EOM_FAULT event
	{
		EPT0->EMICR=EPT_EOM_FAULT_EMINT;
	}
}
/*************************************************************/
//WWDT Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void WWDTIntHandler(void)
{
	WWDT->ICR=0X01;
	WWDT_CNT_Load(0xFF);
	
	if((WWDT->MISR&WWDT_EVI)==WWDT_EVI)
	{
		WWDT->ICR = WWDT_EVI;
	}
}
/*************************************************************/
//DMA Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void DMAIntHandler(void)
{
	 // ISR content ...
	if((DMA->ISR&DMA0_LTCIT)==DMA0_LTCIT)			//CH0 L 完成
	{
		DMA->ICR=DMA0_LTCIT;
	}	
	if((DMA->ISR&DMA1_LTCIT)==DMA1_LTCIT)			//CH1 L 完成
	{
		DMA->ICR=DMA1_LTCIT;
	}
	if((DMA->ISR&DMA2_LTCIT)==DMA2_LTCIT)			//CH2 L 完成
	{
		DMA->ICR=DMA2_LTCIT;
	}
	if((DMA->ISR&DMA3_LTCIT)==DMA3_LTCIT)			//CH3 L 完成
	{
		DMA->ICR=DMA3_LTCIT;
	}
	if((DMA->ISR&DMA4_LTCIT)==DMA4_LTCIT)			//CH4 L 完成
	{
		DMA->ICR=DMA4_LTCIT;
	}
	if((DMA->ISR&DMA5_LTCIT)==DMA5_LTCIT)			//CH5 L 完成
	{
		DMA->ICR=DMA5_LTCIT;
	}
	if((DMA->ISR&DMA0_TCIT)==DMA0_TCIT)				//CH0 L H 完成	
	{
		DMA->ICR=DMA0_TCIT;
	}
	if((DMA->ISR&DMA1_TCIT)==DMA1_TCIT)				//CH1 L H 完成	
	{
		DMA->ICR=DMA1_TCIT;
	}
	if((DMA->ISR&DMA2_TCIT)==DMA2_TCIT)				//CH2 L H 完成	
	{
		DMA->ICR=DMA2_TCIT;
	}
	if((DMA->ISR&DMA3_TCIT)==DMA3_TCIT)				//CH3 L H 完成	
	{
		DMA->ICR=DMA3_TCIT;
	}
	if((DMA->ISR&DMA4_TCIT)==DMA4_TCIT)				//CH4 L H 完成	
	{
		DMA->ICR=DMA4_TCIT;
	}
	if((DMA->ISR&DMA5_TCIT)==DMA5_TCIT)				//CH5 L H 完成	
	{
		DMA->ICR=DMA5_TCIT;
	}
}
/*************************************************************/
//GPTA0 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void GPTA0IntHandler(void) 
{
    // ISR content ...
	if((GPTA0->MISR&GPT_TRGEV0_INT)==GPT_TRGEV0_INT)			//TRGEV0 interrupt
	{
		GPTA0->ICR = GPT_TRGEV0_INT;
	} 
	else if((GPTA0->MISR&GPT_TRGEV1_INT)==GPT_TRGEV1_INT)	//TRGEV1 interrupt
	{
		GPTA0->ICR = GPT_TRGEV1_INT;
	}
	else if((GPTA0->MISR&GPT_CAP_LD0)==GPT_CAP_LD0)		//Capture Load to CMPA interrupt
	{
		GPTA0->ICR = GPT_CAP_LD0;
		//EXTI_trigger_CMD(DISABLE,EXI_PIN0,_EXIRT);
		//EXTI_trigger_CMD(ENABLE,EXI_PIN0,_EXIFT);
		
		//R_CMPA_BUF=GPTA0->CMPA;			//period counter
	}
	else if((GPTA0->MISR&GPT_CAP_LD1)==GPT_CAP_LD1)		//Capture Load to CMPB interrupt
	{
		GPTA0->ICR = GPT_CAP_LD1;
		//EXTI_trigger_CMD(ENABLE,EXI_PIN0,_EXIRT);
		//EXTI_trigger_CMD(DISABLE,EXI_PIN0,_EXIFT);
		//R_CMPB_BUF=GPTA0->CMPB;			//Duty counter
	}
	else if((GPTA0->MISR&GPT_CAU)==GPT_CAU)			//Up-Counting phase CNT = CMPA Interrupt
	{
		GPTA0->ICR = GPT_CAU;
	}
	else if((GPTA0->MISR&GPT_CAD)==GPT_CAD)			//Down-Counting phase CNT = CMPA Interrupt
	{
		GPTA0->ICR = GPT_CAD;
	}
	else if((GPTA0->MISR&GPT_CBU)==GPT_CBU)			//Up-Counting phase CNT = CMPB Interrupt
	{
		GPTA0->ICR = GPT_CBU;
	}
	else if((GPTA0->MISR&GPT_CBD)==GPT_CBD)			//Down-Counting phase CNT = CMPB Interrupt
	{
		GPTA0->ICR = GPT_CBD;
	}
	else if((GPTA0->MISR&GPT_PEND)==GPT_PEND)		//End of cycle interrupt 
	{
		GPTA0->ICR = GPT_PEND;
	}
}
/*************************************************************/
//RTC Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void RTCIntHandler(void) 
{
    // ISR content ...
	if((RTC->MISR&ALRA_INT)==ALRA_INT)			//Interrupt of alarm A
	{
		RTC->ICR=ALRA_INT;
	}
	else if((RTC->MISR&ALRB_INT)==ALRB_INT)			//Interrupt of alarm B				
	{
		RTC->ICR=ALRB_INT;
	}
	else if((RTC->MISR&CPRD_INT)==CPRD_INT)			//Interrupt of alarm CPRD
	{
		RTC->ICR=CPRD_INT;
	}
	else if((RTC->MISR&RTC_TRGEV0_INT)==RTC_TRGEV0_INT)		//Interrupt of trigger event 0
	{
		RTC->ICR=RTC_TRGEV0_INT;
	}
	else if((RTC->MISR&RTC_TRGEV1_INT)==RTC_TRGEV1_INT)		//Interrupt of trigger event 1
	{
		RTC->ICR=RTC_TRGEV1_INT;
	}
}
/*************************************************************/
//UART0 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void UART0IntHandler(void) 
{
    // ISR content ...	
	if ((UART0->ISR&UART_RX_INT_S)==UART_RX_INT_S)				//RX interrupt
	{
		UART0->ISR=UART_RX_INT_S;
		//r_uart_buf[0] = CSP_UART_GET_DATA(UART0);
		//UARTTxByte(UART0,r_uart_buf[0]);
		nop;
	}
	else if( (UART0->ISR&UART_TX_INT_S)==UART_TX_INT_S ) 		//TX interrupt
    {
		UART0->ISR=UART_TX_INT_S;
	}
	else if ((UART0->ISR&UART_RX_IOV_S)==UART_RX_IOV_S)			//RX overrun interrupt
	{
		UART0->ISR=UART_RX_IOV_S;
	}
	else if ((UART0->ISR&UART_TX_IOV_S)==UART_TX_IOV_S)			//TX overrun interrupt
	{
		UART0->ISR=UART_TX_IOV_S;
	}
}
/*************************************************************/
//UART1 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void UART1IntHandler(void) 
{
    // ISR content ...
	if ((UART1->ISR&UART_RX_INT_S)==UART_RX_INT_S)				//RX interrupt
	{
		UART1->ISR=UART_RX_INT_S;
		//r_uart_buf[0] = CSP_UART_GET_DATA(UART1);
		//UARTTxByte(UART1,r_uart_buf[0]);
	}
	else if( (UART1->ISR&UART_TX_INT_S)==UART_TX_INT_S ) 		//TX interrupt
    {
		UART1->ISR=UART_TX_INT_S;
	}
	else if ((UART1->ISR&UART_RX_IOV_S)==UART_RX_IOV_S)			//RX overrun interrupt
	{
		UART1->ISR=UART_RX_IOV_S;
	}
	else if ((UART1->ISR&UART_TX_IOV_S)==UART_TX_IOV_S)			//TX overrun interrupt
	{
		UART1->ISR=UART_TX_IOV_S;
	}
}
/*************************************************************/
//UART2 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void UART2IntHandler(void) 
{
    // ISR content ...
	if ((UART2->ISR&UART_RX_INT_S)==UART_RX_INT_S)				//RX interrupt
	{
		UART2->ISR=UART_RX_INT_S;
		//r_uart_buf[0] = CSP_UART_GET_DATA(UART2);
		//UARTTxByte(UART2,r_uart_buf[0]);
	}
	else if( (UART2->ISR&UART_TX_INT_S)==UART_TX_INT_S ) 		//TX interrupt
    {
		UART2->ISR=UART_TX_INT_S;
	}
	else if ((UART2->ISR&UART_RX_IOV_S)==UART_RX_IOV_S)			//RX overrun interrupt
	{
		UART2->ISR=UART_RX_IOV_S;
	}
	else if ((UART2->ISR&UART_TX_IOV_S)==UART_TX_IOV_S)			//TX overrun interrupt
	{
		UART2->ISR=UART_TX_IOV_S;
	}
}
/*************************************************************/
//USART Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void USART0IntHandler(void) 
{
	unsigned int status;
	status = USART0->MISR & USART0->IMSCR ;
	if( status & USART_RXRDY ) 				// 接收完成
	{
		//r_usart_buf[0]=CSP_USART_GET_RHR(USART0);
		//USART_TxByte(USART0,r_usart_buf[0]);
		USART0->ICR = USART_RXRDY;
	}
	else if (status & USART_TXRDY) 			//发送完成
	{
		USART0->ICR = USART_TXRDY;
	}
	else if (status & USART_RXBRK_INT)		//接收端Break中断
	{
		USART0->ICR = USART_RXBRK_INT;
	}
	else if(status & USART_OVER_INT)		//溢出错误中断
	{
		USART0->ICR = USART_OVER_INT;
	}
	else if(status & USART_FRAME_INT)		//帧错误中断
	{
		USART0->ICR = USART_FRAME_INT;
	}
	else if(status & USART_PARE_INT)		//校验错误中断
	{
		USART0->ICR = USART_PARE_INT;
	}
	else if(status & USART_TIMEOUT_INT)		//超时中断
	{
		USART0->ICR = USART_TIMEOUT_INT;
	}
	else if(status & USART_TXEMPTY_INT)		//发送缓存空闲中断
	{
		USART0->ICR = USART_TXEMPTY_INT;
	}
	else if(status & USART_IDLE_INT)		//空闲中断
	{
		USART0->ICR = USART_IDLE_INT;
	}
	else if(status & USART_RXRIS_INT)		//接收FIFO中断
	{
		USART0->ICR = USART_RXRIS_INT;
	}
	else if(status & USART_RORRIS_INT)		//接收FIFO溢出中断
	{
		USART0->ICR = USART_RORRIS_INT;
	}
	else if(status & USART_TXRIS_INT)		//发送FIFO中断
	{
		USART0->ICR = USART_TXRIS_INT;
	}
	
	if(status & LIN_ENDHEADER_INT)		//LIN帧头结束中断
	{
		USART0->ICR = LIN_ENDHEADER_INT;
	}
	else if(status & LIN_ENDMESS_INT)		//LIN消息结束中断
	{
		USART0->ICR = LIN_ENDMESS_INT;
	}
	else if(status & LIN_NOTREPS_INT)		//LIN 没有响应错误中断
	{

		USART0->ICR = LIN_NOTREPS_INT;
	}
	else if(status & LIN_BITERROR_INT)		//LIN 位错误中断
	{

		USART0->ICR = LIN_BITERROR_INT;
	}
	else if(status & LIN_IPERROR_INT)		//LIN 标识校验错误中断
	{

		USART0->ICR = LIN_IPERROR_INT;
	}
	else if(status & LIN_CHECKSUM_EEROR_INT) //LIN checksum错误中断
	{

		USART0->ICR = LIN_CHECKSUM_EEROR_INT;
	}
	
}
/*************************************************************/
//I2C Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void I2CIntHandler(void) 
{
    // ISR content ...
	//I2C_Slave_Receive();
}
/*************************************************************/
//SPI Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SPI0IntHandler(void) 
{
	// ISR content ...
	if((SPI0->MISR&SPI_PORIM)==SPI_PORIM)					//Receive Overrun Interrupt
	{
		SPI0->ICR = SPI_PORIM;
	} 
	else if((SPI0->MISR&SPI_RTIM)==SPI_RTIM)				//Receive Timeout Interrupt
	{
		SPI0->ICR = SPI_RTIM;
	}
	else if((SPI0->MISR&SPI_RXIM)==SPI_RXIM)				//Receive FIFO Interrupt,FIFO can be set 1/8,1/4,1/2 FIFO Interrupt
	{
		SPI0->ICR = SPI_RXIM;
		if(SPI0->DR==0xaa)
		{
			while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	//FIFO未满？
			SPI0->DR = 0x11;
			while(((SPI0->SR) & SSP_BSY) == SSP_BSY);	//发送或接收完成？
			
			while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	//FIFO未满？
			SPI0->DR = 0x12;
			while(((SPI0->SR) & SSP_BSY) == SSP_BSY);	//发送或接收完成？
			
			while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	//FIFO未满？
			SPI0->DR = 0x13;
			while(((SPI0->SR) & SSP_BSY) == SSP_BSY);	//发送或接收完成？
			
			while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	//FIFO未满？
			SPI0->DR = 0x14;
			while(((SPI0->SR) & SSP_BSY) == SSP_BSY);	//发送或接收完成？
			
			while(((SPI0->SR) & SSP_TNF) != SSP_TNF);	//FIFO未满？
			SPI0->DR = 0x15;
			while(((SPI0->SR) & SSP_BSY) == SSP_BSY);	//发送或接收完成？
			
		}
		else
		{
			if(((SPI0->SR) & SSP_TFE)!=SSP_TFE)
			{
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				SPI0->DR=0x0;								//FIFO空
				while(((SPI0->SR) & SSP_BSY) == SSP_BSY);		//发送或接收是否完成？
			}
		}
	}
	else if((SPI0->MISR&SPI_TXIM)==SPI_TXIM)				//Transmit FIFO Interrupt
	{
		SPI0->ICR = SPI_TXIM;
	}
}
/*************************************************************/
//SIO Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void SIO0IntHandler(void) 
{
    // ISR content ...
	
	//序列小于16bit发送程序
	if(SIO0->MISR&SIO_TXDNE)							//TXDNE
	{
		SIO0->ICR=SIO_TXDNE;
		nop;
	}
	else if(SIO0->MISR&SIO_RXDNE)						//RXDNE 
	{
		SIO0->ICR=SIO_RXDNE;
		//if(R_SIORX_count>=1)
		//{
		//	R_SIORX_buf[R_SIORX_count]=SIO0->RXBUF;			
		//	nop;
		//	R_SIORX_count=0;
		//
	}
	else if(SIO0->MISR&SIO_TXBUFEMPT)
	{
		SIO0->ICR=SIO_TXBUFEMPT;
	}
	else if(SIO0->MISR&SIO_RXBUFEMPT)					//RXBUFFULL	
	{
		SIO0->ICR=SIO_RXBUFEMPT;
		//if(R_SIORX_count<1)
		//{
		//	R_SIORX_buf[R_SIORX_count]=SIO0->RXBUF;		
		//	R_SIORX_count++;
		//}
		//if(R_SIORX_count>=2)
		//	R_SIORX_count=0;
	}
	else if(SIO0->MISR&SIO_BREAK)						//BREAK
	{
		SIO0->ICR=SIO_BREAK;
	}
	else if(SIO0->MISR&SIO_TIME)						//TIMEOUT
	{
		SIO0->ICR=SIO_TIME;
	}
}
/*************************************************************/
//EXT0/16 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EXI0IntHandler(void) 
{
    // ISR content ...
	if ((SYSCON->EXIRS&EXI_PIN0)==EXI_PIN0) 			//EXT0 Interrupt
	{
		SYSCON->EXICR = EXI_PIN0;
	}
	else if ((SYSCON->EXIRS&EXI_PIN16)==EXI_PIN16) 		//EXT16 Interrupt
	{
		SYSCON->EXICR = EXI_PIN16;
	}
}
/*************************************************************/
//EXT1/17 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EXI1IntHandler(void) 
{
    // ISR content ...
	if ((SYSCON->EXIRS&EXI_PIN1)==EXI_PIN1) 			//EXT1 Interrupt
	{
		SYSCON->EXICR = EXI_PIN1;
	}
	else if ((SYSCON->EXIRS&EXI_PIN17)==EXI_PIN17) 		//EXT17 Interrupt
	{
		SYSCON->EXICR = EXI_PIN17;
	}
}
/*************************************************************/
//EXI2~3 18~19Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EXI2to3IntHandler(void) 
{
    // ISR content ...
	if ((SYSCON->EXIRS&EXI_PIN2)==EXI_PIN2) 			//EXT2 Interrupt
	{
		SYSCON->EXICR = EXI_PIN2;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN3)==EXI_PIN3) 		//EXT3 Interrupt
	{
		SYSCON->EXICR = EXI_PIN3;
	}
	else if ((SYSCON->EXIRS&EXI_PIN18)==EXI_PIN18) 		//EXT18 Interrupt
	{
		SYSCON->EXICR = EXI_PIN18;
	}
	else if ((SYSCON->EXIRS&EXI_PIN19)==EXI_PIN19) 		//EXT19 Interrupt
	{
		SYSCON->EXICR = EXI_PIN19;
	}
}
/*************************************************************/
//EXI4~9 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EXI4to9IntHandler(void) 
{
    // ISR content ...
	if ((SYSCON->EXIRS&EXI_PIN4)==EXI_PIN4) 			//EXT4 Interrupt
	{
		SYSCON->EXICR = EXI_PIN4;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN5)==EXI_PIN5) 		//EXT5 Interrupt
	{
		SYSCON->EXICR = EXI_PIN5;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN6)==EXI_PIN6) 		//EXT6 Interrupt
	{
		SYSCON->EXICR = EXI_PIN6;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN7)==EXI_PIN7) 		//EXT7 Interrupt
	{
		SYSCON->EXICR = EXI_PIN7;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN8)==EXI_PIN8) 		//EXT8 Interrupt
	{
		SYSCON->EXICR = EXI_PIN8;
	}
	else if ((SYSCON->EXIRS&EXI_PIN9)==EXI_PIN9) 		//EXT9 Interrupt
	{
		SYSCON->EXICR = EXI_PIN9;
	}
}
/*************************************************************/
//EXI4 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void EXI10to15IntHandler(void) 
{
    // ISR content ...
	if ((SYSCON->EXIRS&EXI_PIN10)==EXI_PIN10) 			//EXT10 Interrupt
	{
		SYSCON->EXICR = EXI_PIN10;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN11)==EXI_PIN11) 		//EXT11 Interrupt
	{
		SYSCON->EXICR = EXI_PIN11;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN12)==EXI_PIN12) 		//EXT12 Interrupt
	{
		SYSCON->EXICR = EXI_PIN12;
	} 
	else if ((SYSCON->EXIRS&EXI_PIN13)==EXI_PIN13) 		//EXT13 Interrupt
	{
		SYSCON->EXICR = EXI_PIN13;
	}
	else if ((SYSCON->EXIRS&EXI_PIN14)==EXI_PIN14) 		//EXT14 Interrupt
	{
		SYSCON->EXICR = EXI_PIN14;
	}
	else if ((SYSCON->EXIRS&EXI_PIN15)==EXI_PIN15) 		//EXT15 Interrupt
	{
		SYSCON->EXICR = EXI_PIN15;
	}
}
/*************************************************************/
//CONTA Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void CNTAIntHandler(void) 
{
    // ISR content ...
	
}
/*************************************************************/
//LPT Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void LPTIntHandler(void) 
{
    // ISR content ...
	if((LPT->MISR&LPT_TRGEV0)==LPT_TRGEV0)			//TRGEV0 interrupt
	{
		LPT->ICR = LPT_TRGEV0;
	} 
	else if((LPT->MISR&LPT_MATCH)==LPT_MATCH)		//MATCH interrupt
	{
		LPT->ICR = LPT_MATCH;
	}
	else if((LPT->MISR&LPT_PEND)==LPT_PEND)			//PEND interrupt
	{
		LPT->ICR = LPT_PEND;
	}
}
/*************************************************************/
//BT0 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void BT0IntHandler(void) 
{
    // ISR content ...
	if((BT0->MISR&BT_PEND)==BT_PEND)				//BT0 PEND interrupt
	{
		BT0->ICR = BT_PEND;
	} 
	else if((BT0->MISR&BT_CMP)==BT_CMP)				//BT0 CMP Match interrupt 
	{
		BT0->ICR = BT_CMP;
	}
	else if((BT0->MISR&BT_OVF)==BT_OVF)				//BT0 OVF interrupt
	{
		BT0->ICR = BT_OVF;
	} 
	else if((BT0->MISR&BT_EVTRG)==BT_EVTRG)			//BT0 Event trigger interrupt
	{
		BT0->ICR = BT_EVTRG;
	}
}
/*************************************************************/
//BT1 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void BT1IntHandler(void) 
{
    // ISR content ...
	if((BT1->MISR&BT_PEND)==BT_PEND)				//BT1 PEND interrupt
	{
		BT1->ICR = BT_PEND;
	} 
	else if((BT1->MISR&BT_CMP)==BT_CMP)				//BT1 CMP Match interrupt 
	{
		BT1->ICR = BT_CMP;
	}
	else if((BT1->MISR&BT_OVF)==BT_OVF)				//BT1 OVF interrupt
	{
		BT1->ICR = BT_OVF;
	} 
	else if((BT1->MISR&BT_EVTRG)==BT_EVTRG)			//BT1 Event trigger interrupt
	{
		BT1->ICR = BT_EVTRG;
	}
}
/*************************************************************/
//BT2 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void BT2IntHandler(void) 
{
    // ISR content ...
	if((BT2->MISR&BT_PEND)==BT_PEND)				//BT2 PEND interrupt
	{
		BT2->ICR = BT_PEND;
	} 
	else if((BT2->MISR&BT_CMP)==BT_CMP)				//BT2 CMP Match interrupt 
	{
		BT2->ICR = BT_CMP;
	}
	else if((BT2->MISR&BT_OVF)==BT_OVF)				//BT2 OVF interrupt
	{
		BT2->ICR = BT_OVF;
	} 
	else if((BT2->MISR&BT_EVTRG)==BT_EVTRG)			//BT2 Event trigger interrupt
	{
		BT2->ICR = BT_EVTRG;
	}
}
/*************************************************************/
//BT3 Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void BT3IntHandler(void) 
{
/*-------------------tkey basecnt-----------------------*/    
	tkey_basecnt_process();
/*------------------------------------------------------*/  	
	// ISR content ...
	if((BT3->MISR&BT_PEND)==BT_PEND)				//BT3 PEND interrupt
	{
		BT3->ICR = BT_PEND;
	} 
	else if((BT3->MISR&BT_CMP)==BT_CMP)				//BT3 CMP Match interrupt 
	{
		BT3->ICR = BT_CMP;
	}
	else if((BT3->MISR&BT_OVF)==BT_OVF)				//BT3 OVF interrupt
	{
		BT3->ICR = BT_OVF;
	} 
	else if((BT3->MISR&BT_EVTRG)==BT_EVTRG)			//BT3 Event trigger interrupt
	{
		BT3->ICR = BT_EVTRG;
	}
}
/*************************************************************/
//Tkey Interrupt
//EntryParameter:NONE
//ReturnValue:NONE
/*************************************************************/
void TKEYIntHandler(void)
{
	tkey_int_process();
}
/*************************************************************/
/*************************************************************/
/*************************************************************/
void tspend_handler(void) 	//软件中断
{
	nop;
}
void INST_FETCH_ERROR_HANDLER(void)					//1 号取指令访问异常处理函数
{
	
}
void ILLEGAL_INST_ERROR_HANDLER(void)				//2 号非法指令异常处理函数
{

}
void Debug_Breakpoint_ERROR_HANDLER(void)			//3 号调试断点异常
{

}
void Load_INST_NoAligned_ACCESS_ERROR_HANDLER(void)	//4 号加载指令非对齐访问异常
{
	
}
void load_INST_ACCESS_ERROR_HANDLER(void)			//5 号加载指令访问错误异常
{
	
}
void Save_INST_NoAligned_ACCESS_ERROR_HANDLER(void)	//6 号存储指令非对齐访问异常
{

}
void Save_INST_ACCESS_ERROR_HANDLER(void)			//7 号存储指令访问错误异常
{
	
}
void UserMode_ECALL_ERROR_HANDLER(void)	//8 号用户模式环境调用异常
{
	
}

void MACHINE_ECALL_HANDLER(void)
{
	
}

/******************* (C) COPYRIGHT 2023 APT Chip *****END OF FILE****/

