/*
 * Copyright (C) 2017-2019 Alibaba Group Holding Limited
 */

/*
 * .text(code)	Code segment, the area where the program execution code is stored 
 * .rodata(ro)	Read-only data segment, storing strings in C and define constants
 * .data(rw) 	Initialize the data segment, store the initialized global variables and static variables in the program 
 * .bss(zi)    	Uninitialized and initialized to 0 data segment, storing uninitialized(initialized to 0) global variables and static variables in the program;
 * .heap		Stores the dynamically allocated memory segment during the running of the process 
 * .stack		Store local variables temporarily created by the program 
 *
 *  RO SIZE 	= (Code + RO Data) = (text + rodata)
 *  RW SIZE 	= (Rw Data + ZI Data) = (data + bss)
 *  ROM SIZE 	= (Code + RO Data + RW Data)
 */
/******************************************************************************
 * @file     gcc_csky.ld
 * @brief    csky linker file
 * @version  V1.0
 * @date     09. June 2021
 ******************************************************************************/
MEMORY
{
	ROM(RX)   : ORIGIN = 0x00000000,  LENGTH = 80K

	RAM(RWX)  : ORIGIN = 0x20000000,  LENGTH = 8K
}

/*heap and stack*/
__heap_size  = 0x00;							/* heap for dynamically allocated memory */	
__stack_top = ORIGIN(RAM) + LENGTH(RAM);
__stack_start = __stack_top - 8; 

/*PROVIDE (__ram_end  = 0x0000C000); */			/* define symbol for external reference*/
/*PROVIDE (__heap_end = __ram_end);  */

REGION_ALIAS("REGION_TEXT",    ROM);			/* Assign alias names to memory regions */
REGION_ALIAS("REGION_RODATA",  ROM);
REGION_ALIAS("REGION_DATA",    RAM);
REGION_ALIAS("REGION_BSS",     RAM);

ENTRY(Reset_Handler)							/* Entrance address */

SECTIONS {
    .text :								
    {
		. = ALIGN(4) ;						/* Align the start of the section */
        *crt0.o (.text)						/* The file linked to the start position is startup.o */
		*crt0.o(.vectors_inrom*)
		*crt0.o(.trap_inrom*)
        *(.text)
		*(.text.*)
    } > REGION_TEXT
	

    .rodata :
    {
		. = ALIGN(0x4) ;
        *(.rodata) 
        *(.rodata.*)
		*(.srodata) 
        *(.srodata.*)
		. = ALIGN(0x4) ; 
        _end_rodata = .;
    } > REGION_RODATA
	
    .data : 
    { 
		. = ALIGN(0x4) ;						/* Align the start of the section */
		_start_data = .;						/* Provide the name for the start of this section */
		*crt0.o(.vectors_inram*)
		*crt0.o(.trap_inram*)
    	*( .data );
		*( .data.* );
		
		*( .sdata );
		*( .sdata.* );
		*(.codeinram);
		. = ALIGN(0x4) ;						/* Align the start of the section */
    	_end_data = .; 							/* Provide the name for the end of this section */
    } > REGION_DATA AT > REGION_RODATA			
   
   .bss :
    {
		. = ALIGN(0x4) ;
		_bss_start = . ;
		*(.sbss)
		*(.sbss.*)
		*(.scommon)
		*(.bss)
		*(.bss.*)
		*(COMMON)
		. = ALIGN(0x4) ;
		_ebss = . ;
		_end = . ;
		end = . ;
    } > REGION_BSS AT > REGION_BSS
	
}

